Module config

Module config 

Structs

ColorRangeIter
ColorSpaceIter
FrameRateIter
PixelFormatIter
SampleFormatIter
SampleRateIter

Enums

Supported

Functions

supported_channel_layouts
Low-level function interacting with the FFmpeg API via avcodec_get_supported_config(). Consider using the convenience method on audio codecs instead.
supported_color_ranges
Low-level function interacting with the FFmpeg API via avcodec_get_supported_config(). Consider using one of the convenience methods on the codecs or codec contexts instead.
supported_color_spaces
Low-level function interacting with the FFmpeg API via avcodec_get_supported_config(). Consider using one of the convenience methods on the codecs or codec contexts instead.
supported_frame_rates
Low-level function interacting with the FFmpeg API via avcodec_get_supported_config(). Consider using one of the convenience methods on the codecs or codec contexts instead.
supported_pixel_formats
Low-level function interacting with the FFmpeg API via avcodec_get_supported_config(). Consider using one of the convenience methods on the codecs or codec contexts instead.
supported_sample_formats
Low-level function interacting with the FFmpeg API via avcodec_get_supported_config(). Consider using one of the convenience methods on the codecs or codec contexts instead.
supported_sample_rates
Low-level function interacting with the FFmpeg API via avcodec_get_supported_config(). Consider using one of the convenience methods on the codecs or codec contexts instead.