DictionaryMut

Struct DictionaryMut 

pub struct DictionaryMut<'d> { /* private fields */ }

Implementations

Source

impl<'a> DictionaryMut<'a>

pub fn get<K: AsRef<str>>(&self, key: K) -> Option<&str>

Try to find a value in the dictionary.

This function uses case-insensitive matching of the entire key string to find a value. If you want to customize the way FFmpeg searches for the key, see get_with_flags.

Source

impl<'a> DictionaryMut<'a>

pub fn get_with_flags<K: AsRef<str>>( &self, key: K, flags: Flags, ) -> Option<&str>

Try to find a value in the dictionary, using custom search flags.

See Flags to see how each flag works. Using Flags::DONT_STRDUP_KEY is heavily discouraged unless you know what you are doing.

Source

impl<'a> DictionaryMut<'a>

pub fn len(&self) -> usize

Returns the number of entries in the dictionary.

Source

impl<'a> DictionaryMut<'a>

pub fn is_empty(&self) -> bool

Returns true if the dictionary is empty.

Source

impl<'a> DictionaryMut<'a>

pub fn iter(&self) -> Iter<'_>

Creates an iterator over all key-value pairs in the dictionary.

Source

impl<'a> DictionaryMut<'a>

pub fn set<K, V>(&mut self, key: K, value: V)
where K: AsRef<str>, V: AsRef<str>,

Set a value for the given key.

This function will overwrite any value that already exists for the given key. If you want to customize the way FFmpeg inserts the new value, see set_with_flags.

Source

impl<'a> DictionaryMut<'a>

pub fn set_with_flags<K, V>(&mut self, key: K, value: V, flags: Flags)
where K: AsRef<str>, V: AsRef<str>,

Set a value for the given key, using custom flags.

See Flags to see how each flag works. Using Flags::DONT_STRDUP_KEY or Flags::DONT_STRDUP_VAL is heavily discouraged unless you know what you are doing.

Source

impl<'a> DictionaryMut<'a>

pub fn unset<K: AsRef<str>>(&mut self, key: K)

Remove a value from the dictionary for the given key.

If you want to customize the way FFmpeg searches for the key, see unset_with_flags.

Source

impl<'a> DictionaryMut<'a>

pub fn unset_with_flags<K: AsRef<str>>(&mut self, key: K, flags: Flags)

Remove a value from the dictionary for the given key, using custom flags.

See Flags to see how each flag works. Using Flags::DONT_STRDUP_KEY or Flags::DONT_STRDUP_VAL is heavily discouraged unless you know what you are doing.

Source

impl<'d> DictionaryMut<'d>

pub fn to_owned(&self) -> Dictionary

Clones the borrowed data into an owned Dictionary.

Source

impl<'d> DictionaryMut<'d>

pub unsafe fn from_raw(ptr: &'d mut *mut AVDictionary) -> Self

pub fn replace_with(&mut self, new: Dictionary)

pub fn as_ptr(&self) -> *const AVDictionary

pub fn as_mut_ptr(&mut self) -> &mut *mut AVDictionary

pub fn as_ref(&self) -> DictionaryRef<'d>