DictionaryRef

Struct DictionaryRef 

pub struct DictionaryRef<'d> { /* private fields */ }

Implementations

Source

impl<'d> DictionaryRef<'d>

pub unsafe fn from_raw(ptr: *const AVDictionary) -> Self

pub fn as_ptr(&self) -> *const AVDictionary

Source

impl<'a> DictionaryRef<'a>

pub fn get<K: AsRef<str>>(&self, key: K) -> Option<&str>

Try to find a value in the dictionary.

This function uses case-insensitive matching of the entire key string to find a value. If you want to customize the way FFmpeg searches for the key, see get_with_flags.

Source

impl<'a> DictionaryRef<'a>

pub fn get_with_flags<K: AsRef<str>>( &self, key: K, flags: Flags, ) -> Option<&str>

Try to find a value in the dictionary, using custom search flags.

See Flags to see how each flag works. Using Flags::DONT_STRDUP_KEY is heavily discouraged unless you know what you are doing.

Source

impl<'a> DictionaryRef<'a>

pub fn len(&self) -> usize

Returns the number of entries in the dictionary.

Source

impl<'a> DictionaryRef<'a>

pub fn is_empty(&self) -> bool

Returns true if the dictionary is empty.

Source

impl<'a> DictionaryRef<'a>

pub fn iter(&self) -> Iter<'_>

Creates an iterator over all key-value pairs in the dictionary.

Source

impl<'d> DictionaryRef<'d>

pub fn to_owned(&self) -> Dictionary

Clones the borrowed data into an owned Dictionary.