pub struct Type(/* private fields */);Implementations
Sourceimpl Type
impl Type
pub const FLAGS: Self
pub const INT: Self
pub const INT64: Self
pub const DOUBLE: Self
pub const FLOAT: Self
pub const STRING: Self
pub const RATIONAL: Self
Sourcepub const BINARY: Self
pub const BINARY: Self
offset must point to a pointer immediately followed by an int
for the length.
pub const DICTIONARY: Self
pub const CONSTANT: Self
Sourcepub const IMAGE_SIZE: Self
pub const IMAGE_SIZE: Self
offset must point to two consecutive ints
pub const PIXEL_FORMAT: Self
pub const SAMPLE_FORMAT: Self
Sourcepub const VIDEO_RATE: Self
pub const VIDEO_RATE: Self
offset must point to AVRational
pub const DURATION: Self
pub const COLOR: Self
pub const CHLAYOUT: Self
pub const C_ULONG: Self
pub const BOOL: Self
Sourcepub const FLAG_ARRAY: Self
pub const FLAG_ARRAY: Self
May be combined with another regular option type to declare an array option.
For array options, AVOption.offset should refer to a pointer
corresponding to the option type. The pointer should be immediately
followed by an unsigned int that will store the number of elements
in the array.
Sourceimpl Type
impl Type
Sourcepub const fn bits(&self) -> c_uint
pub const fn bits(&self) -> c_uint
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: c_uint) -> Option<Self>
pub const fn from_bits(bits: c_uint) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: c_uint) -> Self
pub const fn from_bits_truncate(bits: c_uint) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: c_uint) -> Self
pub const fn from_bits_retain(bits: c_uint) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.