pub struct DictionaryMut<'d> { /* private fields */ }Implementations
Sourceimpl<'a> DictionaryMut<'a>
impl<'a> DictionaryMut<'a>
Sourceimpl<'a> DictionaryMut<'a>
impl<'a> DictionaryMut<'a>
Sourcepub fn get_with_flags<K: AsRef<str>>(
&self,
key: K,
flags: Flags,
) -> Option<&str>
pub fn get_with_flags<K: AsRef<str>>( &self, key: K, flags: Flags, ) -> Option<&str>
Try to find a value in the dictionary, using custom search flags.
See Flags to see how each flag works.
Using Flags::DONT_STRDUP_KEY is heavily discouraged unless you
know what you are doing.
Sourceimpl<'a> DictionaryMut<'a>
impl<'a> DictionaryMut<'a>
Sourceimpl<'a> DictionaryMut<'a>
impl<'a> DictionaryMut<'a>
Sourceimpl<'a> DictionaryMut<'a>
impl<'a> DictionaryMut<'a>
Sourceimpl<'a> DictionaryMut<'a>
impl<'a> DictionaryMut<'a>
Sourceimpl<'a> DictionaryMut<'a>
impl<'a> DictionaryMut<'a>
Sourcepub fn set_with_flags<K, V>(&mut self, key: K, value: V, flags: Flags)
pub fn set_with_flags<K, V>(&mut self, key: K, value: V, flags: Flags)
Set a value for the given key, using custom flags.
See Flags to see how each flag works.
Using Flags::DONT_STRDUP_KEY or Flags::DONT_STRDUP_VAL is
heavily discouraged unless you know what you are doing.
Sourceimpl<'a> DictionaryMut<'a>
impl<'a> DictionaryMut<'a>
Sourcepub fn unset<K: AsRef<str>>(&mut self, key: K)
pub fn unset<K: AsRef<str>>(&mut self, key: K)
Remove a value from the dictionary for the given key.
If you want to customize the way FFmpeg searches for the key,
see unset_with_flags.
Sourceimpl<'a> DictionaryMut<'a>
impl<'a> DictionaryMut<'a>
Sourcepub fn unset_with_flags<K: AsRef<str>>(&mut self, key: K, flags: Flags)
pub fn unset_with_flags<K: AsRef<str>>(&mut self, key: K, flags: Flags)
Remove a value from the dictionary for the given key, using custom flags.
See Flags to see how each flag works.
Using Flags::DONT_STRDUP_KEY or Flags::DONT_STRDUP_VAL is
heavily discouraged unless you know what you are doing.
Sourceimpl<'d> DictionaryMut<'d>
impl<'d> DictionaryMut<'d>
Sourcepub fn to_owned(&self) -> Dictionary
pub fn to_owned(&self) -> Dictionary
Clones the borrowed data into an owned Dictionary.